Struct ZwlrOutputPowerManagerV1
pub struct ZwlrOutputPowerManagerV1 { /* private fields */ }Available on crate feature
wayland and Linux only.Expand description
manager to create per-output power management
This interface is a manager that allows creating per-output power management mode controls.
This interface has no events.
Implementations
impl ZwlrOutputPowerManagerV1
impl ZwlrOutputPowerManagerV1
pub fn get_output_power<U, D>(
&self,
output: &WlOutput,
qh: &QueueHandle<D>,
udata: U,
) -> ZwlrOutputPowerV1
pub fn get_output_power<U, D>( &self, output: &WlOutput, qh: &QueueHandle<D>, udata: U, ) -> ZwlrOutputPowerV1
get a power management for an output
Create an output power management mode control that can be used to adjust the power management mode for a given output.
pub fn destroy(&self)
pub fn destroy(&self)
destroy the manager
All objects created by the manager will still remain valid, until their appropriate destroy request has been called.